@@ -1,5 +1,5 @@
 import base64
-
+import six.moves.urllib as urllib
 
 def decodeImage(imgstring, fileName):
     imgdata = base64.b64decode(imgstring)
@@ -10,4 +10,9 @@ def decodeImage(imgstring, fileName):
 
 def encodeImageIntoBase64(croppedImagePath):
     with open(croppedImagePath, "rb") as f:
-        return base64.b64encode(f.read())
\ No newline at end of file
+        return base64.b64encode(f.read())
+
+
+def download_model(base_url, model_path, model_name):
+    opener = urllib.request.URLopener()
+    opener.retrieve(base_url + model_path, model_name)
